@@ -127,27 +127,34 @@ root_rules = matrix(c(
   '.+[.]Rproj$',   '^Version: '
 ), ncol = 2, byrow = TRUE, dimnames = list(NULL, c('file', 'pattern')))
 
-#' Get the relative path of a path relative a directory
+#' Get the relative path of a path relative to a directory
 #'
 #' Given a directory, return the relative path that is relative to this
 #' directory. For example, the path \file{foo/bar.txt} relative to the directory
 #' \file{foo/} is \file{bar.txt}, and the path \file{/a/b/c.txt} relative to
 #' \file{/d/e/} is \file{../../a/b/c.txt}.
 #' @param dir Path to a directory.
-#' @param x The path to be converted to a relative path.
+#' @param x A vector of paths to be converted to relative paths.
 #' @param use.. Whether to use double-dots (\file{..}) in the relative path. A
 #'   double-dot indicates the parent directory (starting from the directory
 #'   provided by the \code{dir} argument).
-#' @param error Whether to signal an error if the path cannot be converted to a
+#' @param error Whether to signal an error if a path cannot be converted to a
 #'   relative path.
-#' @return A relative path if the conversion succeeded; otherwise the original
-#'   path when \code{error = FALSE}, and an error when \code{error = TRUE}.
+#' @return A vector of relative paths if the conversion succeeded; otherwise the
+#'   original paths when \code{error = FALSE}, and an error when \code{error =
+#'   TRUE}.
 #' @export
 #' @examples
 #' xfun::relative_path('foo/bar.txt', 'foo/')
 #' xfun::relative_path('foo/bar/a.txt', 'foo/haha/')
 #' xfun::relative_path(getwd())
 relative_path = function(x, dir = '.', use.. = TRUE, error = TRUE) {
+  res = x
+  for (i in seq_along(x)) res[i] = relative_path_one(x[i], dir, use.., error)
+  res
+}
+
+relative_path_one = function(x, dir, use.., error) {
   # on Windows, if a relative path doesn't exist, normalizePath() will use
   # getwd() as its parent dir; however, normalizePath() just returns the
   # relative path on *nix, and we have to assume it's relative to getwd()
@@ -366,6 +373,7 @@ file_exists = function(x) file_test('-f', x)
 #' @param ... Other arguments to be passed to \code{\link{dir.create}()}.
 #' @return A logical value indicating if the directory either exists or is
 #'   successfully created.
+#' @export
 dir_create = function(x, recursive = TRUE, ...) {
   dir_exists(x) || dir.create(x, recursive = recursive)
 }
@@ -449,6 +457,26 @@ url_filename = function(x) {
 #' @export
 del_empty_dir = function(dir) {
   if (is.null(dir) || !dir_exists(dir)) return()
-  files = list.files(dir, all.files = TRUE)
+  files = list.files(dir, all.files = TRUE, no.. = TRUE)
   if (length(files) == 0) unlink(dir, recursive = TRUE)
 }
+
+#' Mark some paths as directories
+#'
+#' Add a trailing backlash to a file path if this is a directory. This is useful
+#' in messages to the console for example to quickly identify directories from
+#' files.
+#'
+#' If \code{x} is a vector of relative paths, directory test is done with
+#' path relative to the current working dir. Use \code{xfun::\link{in_dir}()} or
+#' use absolute paths.
+#'
+#' @param x Character vector of paths to files and directories.
+#' @examples
+#' mark_dirs(list.files(find.package("xfun"), full.names = TRUE))
+#' @export
+mark_dirs = function(x) {
+  i = dir_exists(x) & !grepl("/$", x)
+  x[i] = paste0(x[i], "/")
+  x
+}
